Module pairing
zyga
0.5.1
Module pairing
Module Items
Structs
Functions
In crate zyga
zyga
Module
pairing
Structs

Pairing
Proof
Functions

create_
proving_
key
Create proving key and verification key from compiled constraints
generate_
proof
Generate a proof using proving key and witness values
generate_
trusted_
setup
Generate trusted setup parameters